==> eptl-0.0.1.tgz: package/test.js <==
const test = require('ava');
const { parse, replace } = require('./index.js');

test('parse eptl success', t => {
  const info = parse(`
  process.env.HTTP_PORT = '{_ .HTTP_PORT 8080}}';
  process.env.HTTP_PORT = '{{_ .1HTTP_PORT 8080}}';
  process.env.HTTP_WORKER_CONNECTIONS = '{{_ .HTTP_WORKER_CONNECTIONS 512}}';
  process.env.WORKER_PROCESSES = '{{_ .WORKER_PROCESSES 0}}';
  process.env.STATSD_URL = '{{_ .ELE_STATSD_URL "127.0.0.1:8125"}}';
  process.env.TESTING = '{{_ .TESTING true}}';
  `);
  t.deepEqual(info, [
    {
      'key': 'HTTP_WORKER_CONNECTIONS',
      'value': 512,
      'position': {
        'start': 144,
        'end': 178
      }
    },
    {
      'key': 'WORKER_PROCESSES',
      'value': 0,
      'position': {
        'start': 215,
        'end': 240
      }
    },
    {
      'key': 'ELE_STATSD_URL',
      'value': '127.0.0.1:8125',
      'position': {
        'start': 271,
        'end': 309
      }
    },
    {
      'key': 'TESTING',
      'value': true,
      'position': {
        'start': 337,
        'end': 356
      }
    }
  ]);
});

test('replace eptl success', t => {
  const str = replace(`
  process.env.HTTP_PORT = '{{_ .HTTP_PORT 8080}}';
  process.env.HTTP_WORKER_CONNECTIONS = '{{_ .HTTP_WORKER_CONNECTIONS 512}}';
  process.env.WORKER_PROCESSES = '{{_ .WORKER_PROCESSES 0}}';
  process.env.STATSD_URL = '{{_ .ELE_STATSD_URL "127.0.0.1:8125"}}';
  process.env.TESTING = '{{_ .TESTING true}}';
  `, {TESTING: false, HTTP_PORT: 80, ELE_STATSD_URL: '127.0.0.1:110'});
  t.deepEqual(str, `
  process.env.HTTP_PORT = '80';
  process.env.HTTP_WORKER_CONNECTIONS = '512';
  process.env.WORKER_PROCESSES = '0';
  process.env.STATSD_URL = '127.0.0.1:110';
  process.env.TESTING = 'false';
  `);
});

==> eptl-0.0.3.tgz: package/test.js <==
const test = require('ava');
const { parse, replace } = require('./index.js');

test('parse eptl success', t => {
  const info = parse(`
  process.env.HTTP_PORT = '{_ .HTTP_PORT 8080}}';
  process.env.HTTP_PORT = '{{_ .1HTTP_PORT 8080}}';
  process.env.HTTP_PORT = '{{_ .HTTP_PORT 8080';
  process.env.HTTP_PORT = '{{_ .HTTP_PORT }}';
  process.env.HTTP_WORKER_CONNECTIONS = '{{_ .HTTP_WORKER_CONNECTIONS 512}}';
  process.env.WORKER_PROCESSES = '{{_ .WORKER_PROCESSES 0}}';
  process.env.STATSD_URL = '{{_ .ELE_STATSD_URL "127.0.0.1:8125"}}';
  process.env.TESTING = '{{_ .TESTING true}}';
  `);
  t.deepEqual(info, [
    {
      'key': 'HTTP_PORT',
      'value': {
        'default': false,
        'value': ''
      },
      'position': {
        'start': 179,
        'end': 196
      }
    },
    {
      'key': 'HTTP_WORKER_CONNECTIONS',
      'value': {
        'default': true,
        'value': 512
      },
      'position': {
        'start': 240,
        'end': 274
      }
    },
    {
      'key': 'WORKER_PROCESSES',
      'value': {
        'default': true,
        'value': 0
      },
      'position': {
        'start': 311,
        'end': 336
      }
    },
    {
      'key': 'ELE_STATSD_URL',
      'value': {
        'default': true,
        'value': '127.0.0.1:8125'
      },
      'position': {
        'start': 367,
        'end': 405
      }
    },
    {
      'key': 'TESTING',
      'value': {
        'default': true,
        'value': true
      },
      'position': {
        'start': 433,
        'end': 452
      }
    }
  ]);
});

test('replace eptl success', t => {
  const str = replace(`
  process.env.TT = '{{_ .TT }}';
  process.env.HTTP_PORT = '{{_ .HTTP_PORT 8080}}';
  process.env.HTTP_WORKER_CONNECTIONS = '{{_ .HTTP_WORKER_CONNECTIONS 512}}';
  process.env.WORKER_PROCESSES = '{{_ .WORKER_PROCESSES 0}}';
  process.env.STATSD_URL = '{{_ .ELE_STATSD_URL "127.0.0.1:8125"}}';
  process.env.TESTING = '{{_ .TESTING true}}';
  `, {TESTING: false, HTTP_PORT: 80, ELE_STATSD_URL: '127.0.0.1:110'});
  t.deepEqual(str, `
  process.env.TT = '{{_ .TT }}';
  process.env.HTTP_PORT = '80';
  process.env.HTTP_WORKER_CONNECTIONS = '512';
  process.env.WORKER_PROCESSES = '0';
  process.env.STATSD_URL = '127.0.0.1:110';
  process.env.TESTING = 'false';
  `);
});
